## OFSC

A simple Python wrapper for Oracle OFS REST API

## Functions implemented


### Core / Activities
    get_activities (self, params, response_type=TEXT_RESPONSE)
    get_activity (self, activity_id, response_type=TEXT_RESPONSE):
    update_activity (self, activity_id, data, response_type=TEXT_RESPONSE)
    move_activity (self, activity_id, data, response_type=TEXT_RESPONSE)

### Core / Events
    get_subscriptions(self, response_type=TEXT_RESPONSE)
    create_subscription(self, data, response_type=TEXT_RESPONSE):
    get_subscription_details(self, subscription_id, response_type=TEXT_RESPONSE)
    get_events(self, params, response_type=TEXT_RESPONSE)

### Core / Resources
    get_resource(self, resource_id, inventories=False, workSkills=False, workZones=False, workSchedules=False , response_type=TEXT_RESPONSE)
    get_position_history(self, resource_id,date,response_type=TEXT_RESPONSE)
    get_resource_route(self, resource_id, date, activityFields = None, offset=0, limit=100, response_type=TEXT_RESPONSE)
    get_resource_descendants(self, resource_id,  resourceFields=None, offset=0, limit=100, inventories=False, workSkills=False, workZones=False, workSchedules=False, response_type=TEXT_RESPONSE)



### Metadata / Capacity
    get_capacity_areas (self, expand="parent", fields=capacityAreasFields, status="active", queryType="area", response_type=FULL_RESPONSE):
    get_capacity_area (self,label, response_type=FULL_RESPONSE)


## Test History

OFS REST API Version | PyOFSC
------------ | -------------
20C| 1.7

